@@ -2,9 +2,14 @@
 # Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
 
 from . import utils
-from .per_sample_gradient_clip import PerSampleGradientClipper
+from .grad_sample import GradSampleModule
 from .privacy_engine import PrivacyEngine
 from .version import __version__
 
 
-__all__ = ["PrivacyEngine", "PerSampleGradientClipper", "utils", "__version__"]
+__all__ = [
+    "PrivacyEngine",
+    "GradSampleModule",
+    "utils",
+    "__version__",
+]
