@@ -5,21 +5,16 @@ from .conv import compute_conv_grad_sample  # noqa
 from .dp_multihead_attention import compute_sequence_bias_grad_sample  # noqa
 from .dp_rnn import compute_rnn_linear_grad_sample  # noqa
 from .embedding import compute_embedding_grad_sample  # noqa
-from .grad_sample_module import GradSampleModule
+from .grad_sample_module import GradSampleModule, create_or_accumulate_grad_sample
 from .group_norm import compute_group_norm_grad_sample  # noqa
 from .instance_norm import compute_instance_norm_grad_sample  # noqa
 from .layer_norm import compute_layer_norm_grad_sample  # noqa
 from .linear import compute_linear_grad_sample  # noqa
-from .utils import (
-    create_or_accumulate_grad_sample,
-    create_or_extend_grad_sample,
-    register_grad_sampler,
-)
+from .utils import register_grad_sampler
 
 
 __all__ = [
     "GradSampleModule",
     "register_grad_sampler",
     "create_or_accumulate_grad_sample",
-    "create_or_extend_grad_sample",
 ]
