@@ -180,6 +180,10 @@ def _get_flat_grad_sample(p: torch.Tensor):
         raise ValueError(
             "Per sample gradient not found. Are you using GradSampleModule?"
         )
+    if p.grad_sample is None:
+        raise ValueError(
+            "Per sample gradient is not initialized. Not updated in backward pass?"
+        )
     if isinstance(p.grad_sample, torch.Tensor):
         return p.grad_sample
     elif isinstance(p.grad_sample, list):
@@ -263,6 +267,7 @@ class DPOptimizer(Optimizer):
         self.secure_mode = secure_mode
 
         self.param_groups = optimizer.param_groups
+        self.defaults = self.original_optimizer.defaults
         self.state = optimizer.state
         self._step_skip_queue = []
         self._is_last_step_skipped = False
@@ -478,7 +483,7 @@ class DPOptimizer(Optimizer):
                 closure()
 
         if self.pre_step():
-            return self.original_optimizer.step(closure)
+            return self.original_optimizer.step()
         else:
             return None
 
